%  function bsp= bspline(n,x,xmin,delta)
%
%  Cubic B-spline evaluation function.
%  Returns B(n,x), where n is the number of the grid point at which the
%  function is centered.
%
%       n     : number of grid point.
%       x     : 
%       xmin  : Starting x-position for where splines are defined.
%       delta : sub-interval of splines.
%               Return value (dx) from
%               [x dx] = bsplinefit(...).
%
%  The interval on which the splines are
%  defined begins at xmin and has subintervals
%  of length delta.  
%
%  The function returns B(n,x)
%  where n is the number of the grid point at which
%  the function is centered.  If there are N
%  subintervals then there are N+1 grid points.
%  B(1,x) is centered at xmin while B(N+1,x) is
%  centered at xmax.  You can use any value of
%  n you like, however, and this function will
%  just be centered at the appropriate position.
%  x is the argument of the function and can be
%  a single value or an array in usual MATLAB
%  fashion
%
%

function bsp = bspline(n,x,xmin,delta)

   t=abs((x-xmin)/delta+1-n);

%  f1 is one between 0 and 1, zero elsewhere

   f1 = fix(2./(t+1.000000000001));

%  f2 is one between 1 and 2, zero elsewhere

   f2 = fix(3./(t+1.000000000001)).*(1-f1);

   bsp = f1.*(1 + (1-t).*(3 + (1-t).*(3 -3*(1-t) ) ) ) + ...
         f2.*(2-t).^3;

   bsp = bsp/6;

endfunction
