% Function to solve b = a*x by Gaussian elimination where
% the matrix a is a packed tridiagonal matrix
% Input -
%   a = Packed tridiagonal matrix, N by N unpacked
%   b = Column vector of length N
% Output -
%   x = Solution of b = a*x; Column vector of length N

function x = tri_ge(a,b)
    [N,M] = size(a);
    [NN,MM] = size(b);

    if( N ~= NN | MM ~= 1)
        error('Problem in tri_ge, inputs are incompatible');
        usage('tri_ge');
    end

    %%%% Unpack diagonals of triangular matrix into vectors %%%%
    alpha(1:N-1,1) = a(2:N,1);
    beta(1:N,1) = a(1:N,2);
    gamma(1:N-1,1) = a(1:N-1,3);

    %%%% Forward elimination %%%%
    for i=2:N
        coeff = alpha(i-1,1)/beta(i-1,1);
        beta(i,1) = beta(i,1) - coeff*gamma(i-1,1);
        b(i) = b(i) - coeff*b(i-1);
    end

    %%%% Back Substitution %%%%
    x(N) = b(N)/beta(N,1);
    for i=N-1:-1:1
        x(i) = (b(i) - gamma(i,1)*x(i+1))/beta(i,1);
    end

    x = x;   % Return x as a column vector
return;
